#
# spec file for package munin
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define	htmldir /srv/www/htdocs/munin
%define	cgidir /srv/www/cgi-bin
%define	dbdir %{_localstatedir}/lib/munin
%define	logdir %{_localstatedir}/log/munin
%define plugindir %{_prefix}/lib/munin/plugins
%define active_by_default 0
Name:           munin
Version:        2.0.72
Release:        9.2
Summary:        Network-wide graphing framework (grapher/gatherer)
License:        GPL-2.0-only
Group:          System/Monitoring
URL:            https://munin-monitoring.org/
Source0:        https://codeload.github.com/munin-monitoring/munin/tar.gz/refs/tags/%{version}#/%{name}-%{version}.tar.gz
Source1:        Makefile.config
Source2:        munin-node.rc
Source3:        munin.cron.d
Source4:        munin.logrotate
Source5:        munin-node.logrotate
Source6:        munin-node.xml
Source7:        plugins.conf
Source8:        munin-node.tmpfiles
Source9:        munin-node.service
Source10:       munin-cgi-graph.service
Source11:       munin-cgi-html.service
# https://github.com/ifad/nginx-munin/archive/master.zip
Source12:       nginx-munin.zip
# https://github.com/ifad/gsa-munin/archive/master.zip
Source13:       gsa-munin.zip
Source14:       munin-cron.timer
Source15:       munin-cron.service
# Source16:       http://downloads.munin-monitoring.org/%{name}/stable/%{version}/%{name}-%{version}.tar.gz.asc
# 0x910846ADEE4C5D67C19B3E6F0A24C05998BA4133
Source17:       munin.keyring
Patch1:         perl526.patch
# PATCH-FIX-UPSTREAM Use IO::Socket::IP instead of IO::Socket::INET[6]
Patch2:         munin-remove-deprecated-INET6.patch
BuildRequires:  firewall-macros
BuildRequires:  html2text
BuildRequires:  htmldoc
BuildRequires:  pkgconfig
BuildRequires:  python-rpm-macros
BuildRequires:  shadow
BuildRequires:  unzip
BuildRequires:  perl(HTML::Template)
BuildRequires:  perl(Log::Log4perl)
BuildRequires:  perl(Module::Build)
BuildRequires:  perl(Net::SNMP)
BuildRequires:  perl(Net::SSLeay)
BuildRequires:  perl(Net::Server)
BuildRequires:  pkgconfig(systemd)
Requires:       perl-base = %{perl_version}
Requires:       perl-rrdtool
Requires:       rrdtool
Requires:       shadow
Requires:       spawn-fcgi
Requires:       perl(FCGI)
Requires:       perl(Date::Manip)
Requires:       perl(File::Copy::Recursive)
Requires:       perl(HTML::Template)
Requires:       perl(IO::Socket::IP)
Requires:       perl(Log::Log4perl)
Requires:       perl(Munin::Common::Defaults)
Requires:       perl(Net::SNMP)
Requires:       perl(Net::SSLeay)
Requires:       perl(Net::Server)
Requires:       perl(URI)
Recommends:     logrotate
Provides:       group(munin)
Provides:       user(munin)
BuildArch:      noarch
%{?systemd_ordering}
%if 0%{?suse_version} <= 1510
Recommends:     cron
%endif

%description
Munin is a highly flexible and powerful solution used to create graphs of
virtually everything imaginable throughout your network, while still
maintaining a rattling ease of installation and configuration.

This package contains the grapher/gatherer. You will only need one instance of
it in your network. It will periodically poll all the nodes in your network
it's aware of for data, which it in turn will use to create graphs and HTML
pages, suitable for viewing with your graphical web browser of choice.

Munin is written in Perl, and relies heavily on Tobi Oetiker's excellent
RRDtool.

%package node
Summary:        Network-wide graphing framework (node)
# some scripts need logtail which is part of package logdigest in openSUSE
# problem with logdigest is that it installs a cronjob for itself which
# might be unwanted
Group:          System/Monitoring
Requires:       perl-HTML-Template
Requires:       perl-Log-Log4perl
Requires:       perl-Net-SNMP
Requires:       perl-Net-SSLeay
Requires:       perl-Net-Server
Requires:       perl-base = %{perl_version}
Requires:       perl-libwww-perl
Requires:       ps
Requires:       ruby
Requires:       shadow
Requires:       sysstat
Requires(pre):  group(nobody)
Requires(pre):  group(www)
Requires(pre):  user(nobody)
Recommends:     logdigest
Recommends:     logrotate
BuildArch:      noarch
%{?systemd_ordering}

%description node
Munin is a highly flexible and powerful solution used to create graphs of
virtually everything imaginable throughout your network, while still
maintaining a rattling ease of installation and configuration.

This package contains node software. You should install it on all the nodes
in your network. It will know how to extract all sorts of data from the
node it runs on, and will wait for the gatherer to request this data for
further processing.

It includes a range of plugins capable of extracting common values such as
cpu usage, network usage, load average, and so on. Creating your own plugins
which are capable of extracting other system-specific values is very easy,
and is often done in a matter of minutes. You can also create plugins which
relay information from other devices in your network that can't run Munin,
such as a switch or a server running another operating system, by using
SNMP or similar technology.

Munin is written in Perl, and relies heavily on Tobi Oetiker's excellent
RRDtool. To see a real example of Munin in action, take a peek at
<http://www.linpro.no/projects/munin/example/>.

%prep
%setup -q
cp %{SOURCE1} .
unzip %{SOURCE12}
unzip %{SOURCE13}
%patch -P 1 -p1
%patch -P 2 -p1

%build
%__make HOSTNAME=yourhostname

%install
%makeinstall
%__mkdir_p %{buildroot}/%{_sysconfdir}/munin/plugins
%__mkdir_p %{buildroot}/%{_sysconfdir}/munin/munin-conf.d

%__mkdir_p %{buildroot}%{_sysconfdir}/logrotate.d
%__install -m0644 %{SOURCE4} %{buildroot}/%{_sysconfdir}/logrotate.d/munin
%__install -m0644 %{SOURCE5} %{buildroot}/%{_sysconfdir}/logrotate.d/munin-node

%__install -m0644 %{SOURCE7} %{buildroot}/%{_sysconfdir}/munin/plugin-conf.d/munin-node

%__mkdir_p %{buildroot}%{_sbindir}
%__ln_s service %{buildroot}%{_sbindir}/rcmunin-node
%__ln_s service %{buildroot}%{_sbindir}/rcmunin-cgi-graph
%__ln_s service %{buildroot}%{_sbindir}/rcmunin-cgi-html

%__mkdir_p %{buildroot}/%{_prefix}/lib/tmpfiles.d
%__install -m0644 %{SOURCE8} %{buildroot}/%{_prefix}/lib/tmpfiles.d/munin.conf
%__install -m0644 %{SOURCE8} %{buildroot}/%{_prefix}/lib/tmpfiles.d/munin-node.conf
%__mkdir_p %{buildroot}/%{_unitdir}
%__install -m0644 %{SOURCE9} %{buildroot}/%{_unitdir}/munin-node.service
%__install -m0644 %{SOURCE10} %{buildroot}/%{_unitdir}/munin-cgi-graph.service
%__install -m0644 %{SOURCE11} %{buildroot}/%{_unitdir}/munin-cgi-html.service
%if 0%{?suse_version} > 1510
%__install -m0644 %{SOURCE14} %{buildroot}/%{_unitdir}/
%__install -m0644 %{SOURCE15} %{buildroot}/%{_unitdir}/
%else
%__mkdir_p %{buildroot}/%{_sysconfdir}/cron.d
%__install -m0644 %{SOURCE3} %{buildroot}/%{_sysconfdir}/cron.d/munin
%endif

%__mkdir_p %{buildroot}/%{logdir}
%__mkdir_p %{buildroot}/%{htmldir}
%__mkdir_p %{buildroot}/%{dbdir}
%__mkdir_p %{buildroot}/%{dbdir}/plugin-state

%__install -m0755 nginx-munin-master/nginx_* %{buildroot}/%{plugindir}
ln nginx-munin-master/README.org README.nginx

%__install -m0755 munin-gsa-master/snmp_* %{buildroot}/%{plugindir}
ln munin-gsa-master/README.md README.gsa

%if %{suse_version} >= 1600
%python3_fix_shebang_path %{buildroot}/%{plugindir}/*
%endif

# Fix rpmlint warning: This script uses 'env' as an interpreter.
for F in \
	%{buildroot}/%{_prefix}/lib/munin/plugins/ipmi_sensor_ \
	%{buildroot}/%{_prefix}/lib/munin/plugins/smart_ \
	; do
	sed -i -e 's|^#!%{_bindir}/env python|#!%{_bindir}/python3|' $F
done
for F in \
	%{buildroot}/%{_prefix}/lib/munin/plugins/tomcat_ \
	; do
	sed -i -e 's|^#!%{_bindir}/env ruby|#!%{_bindir}/ruby|' $F
done

# firewalld
install -D -m 644 %{SOURCE6} %{buildroot}%{_prefix}/lib/firewalld/services/munin-node.xml

%pre
getent group munin >/dev/null || %{_sbindir}/groupadd -r munin
getent passwd munin > /dev/null || %{_sbindir}/useradd -r -c "munin monitoring" -d %{dbdir} -g munin munin
%service_add_pre munin-cgi-graph.service
%service_add_pre munin-cgi-html.service
%if 0%{?suse_version} > 1510
%service_add_pre munin-cron.timer
%service_add_pre munin-cron.service
%endif

%post
%tmpfiles_create munin.conf
%service_add_post munin-cgi-graph.service
%service_add_post munin-cgi-html.service
%if 0%{?suse_version} > 1510
%service_add_post munin-cron.timer
%service_add_post munin-cron.service
# update from cron based release
if [ -f  %{_sysconfdir}/cron.d/munin ]; then
  systemctl enable munin-cron.timer || :
  systemctl start munin-cron.timer || :
fi
%endif

%preun
%service_del_preun munin-cgi-graph.service
%service_del_preun munin-cgi-html.service
%if 0%{?suse_version} > 1510
%service_del_preun munin-cron.timer
%service_del_preun munin-cron.service
%endif

%postun
%service_del_postun munin-cgi-graph.service
%service_del_postun munin-cgi-html.service
%if 0%{?suse_version} > 1510
%service_del_postun munin-cron.timer
%service_del_postun munin-cron.service
%endif

## Node
%pre node
getent group munin >/dev/null || %{_sbindir}/groupadd -r munin
getent passwd munin > /dev/null || %{_sbindir}/useradd -r -c "munin monitoring" -d %{dbdir} -g munin munin
%service_add_pre munin-node.service

%post node
if [ $1 = 1 ]; then
%{_sbindir}/munin-node-configure --shell | sh
fi
%tmpfiles_create munin-node.conf
%service_add_post munin-node.service
%firewalld_reload

%preun node
%service_del_preun munin-node.service

%postun node
%service_del_postun munin-node.service

%files
%license COPYING
%doc ChangeLog README UPGRADING
%{_bindir}/munin-check
%{_bindir}/munin-cron
%{_bindir}/munindoc
%dir %{_prefix}/lib/munin
%{_prefix}/lib/munin/munin-graph
%{_prefix}/lib/munin/munin-html
%{_prefix}/lib/munin/munin-datafile2storable
%{_prefix}/lib/munin/munin-storable2datafile
%{_prefix}/lib/munin/munin-limits
%{_prefix}/lib/munin/munin-update
%{_prefix}/lib/munin/DejaVuSans.ttf
%{_prefix}/lib/munin/DejaVuSansMono.ttf
%dir %{cgidir}
%{cgidir}/munin-cgi-graph
%{cgidir}/munin-cgi-html
%{_prefix}/lib/tmpfiles.d/munin.conf
%{_unitdir}/munin-cgi-graph.service
%{_unitdir}/munin-cgi-html.service
%{_sbindir}/rcmunin-cgi-graph
%{_sbindir}/rcmunin-cgi-html
%if 0%{?suse_version} > 1510
%{_unitdir}/munin-cron.*
%else
%dir %{_sysconfdir}/cron.d
%config %{_sysconfdir}/cron.d/munin
%endif
%dir /srv/www
%dir /srv/www/htdocs
%attr(0755, munin, munin) %dir %{htmldir}
%attr(0444, munin, munin) %{htmldir}/.htaccess
%dir %{_sysconfdir}/munin
%dir %{_sysconfdir}/munin/munin-conf.d
%dir %{_sysconfdir}/munin/templates
%dir %{_sysconfdir}/munin/static
%config %{_sysconfdir}/munin/templates/*
%config %{_sysconfdir}/munin/static/*
%config(noreplace) %{_sysconfdir}/munin/munin.conf
%config %{_sysconfdir}/logrotate.d/munin
%dir %{perl_vendorlib}/Munin
%dir %{perl_vendorlib}/Munin/Master
%{perl_vendorlib}/Munin/Master/Config.pm
%{perl_vendorlib}/Munin/Master/GraphOld.pm
%{perl_vendorlib}/Munin/Master/Group.pm
%{perl_vendorlib}/Munin/Master/GroupRepository.pm
%{perl_vendorlib}/Munin/Master/HTMLConfig.pm
%{perl_vendorlib}/Munin/Master/HTMLOld.pm
%{perl_vendorlib}/Munin/Master/Host.pm
%{perl_vendorlib}/Munin/Master/LimitsOld.pm
%{perl_vendorlib}/Munin/Master/Logger.pm
%{perl_vendorlib}/Munin/Master/Node.pm
%{perl_vendorlib}/Munin/Master/ProcessManager.pm
%{perl_vendorlib}/Munin/Master/Update.pm
%{perl_vendorlib}/Munin/Master/UpdateWorker.pm
%{perl_vendorlib}/Munin/Master/Utils.pm
%{perl_vendorlib}/Munin/Master/Worker.pm
%{_mandir}/man3/Munin::Master::Config.3pm.gz
%{_mandir}/man3/Munin::Master::Group.3pm.gz
%{_mandir}/man3/Munin::Master::GroupRepository.3pm.gz
%{_mandir}/man3/Munin::Master::HTMLOld.3pm.gz
%{_mandir}/man3/Munin::Master::Host.3pm.gz
%{_mandir}/man3/Munin::Master::LimitsOld.3pm.gz
%{_mandir}/man3/Munin::Master::Logger.3pm.gz
%{_mandir}/man3/Munin::Master::Node.3pm.gz
%{_mandir}/man3/Munin::Master::ProcessManager.3pm.gz
%{_mandir}/man3/Munin::Master::Update.3pm.gz
%{_mandir}/man3/Munin::Master::UpdateWorker.3pm.gz
%{_mandir}/man3/Munin::Master::Utils.3pm.gz
%{_mandir}/man3/Munin::Master::Worker.3pm.gz
%{_mandir}/man5/munin-node.conf.5%{?ext_man}
%{_mandir}/man5/munin.conf.5%{?ext_man}
%{_mandir}/man8/munin-check.8%{?ext_man}
%{_mandir}/man8/munin-cron.8%{?ext_man}
%{_mandir}/man8/munin-graph.8%{?ext_man}
%{_mandir}/man8/munin-html.8%{?ext_man}
%{_mandir}/man8/munin-limits.8%{?ext_man}
%{_mandir}/man8/munin-update.8%{?ext_man}
%{_mandir}/man8/munin.8%{?ext_man}
%attr(0750, munin, munin) %dir %{logdir}
%attr(0755, munin, munin) %dir %{dbdir}
%ghost %attr(0644, munin, munin) %{logdir}/munin-graph.log
%ghost %attr(0644, munin, munin) %{logdir}/munin-html.log
%ghost %attr(0644, munin, munin) %{logdir}/munin-nagios.log
%ghost %attr(0644, munin, munin) %{logdir}/munin-limits.log
%ghost %attr(0644, munin, munin) %{logdir}/munin-update.log
%ghost /run/munin

%files node
%doc README.nginx README.gsa
%{_sbindir}/munin-run
%{_sbindir}/munin-node
%{_sbindir}/munin-node-configure
%{_bindir}/munin-get
%{_prefix}/lib/tmpfiles.d/munin-node.conf
%{_unitdir}/munin-node.service
%dir %{_prefix}/lib/munin
%{_prefix}/lib/munin/munin-async
%{_prefix}/lib/munin/munin-asyncd
%{_prefix}/lib/munin/plugins/
%{_sbindir}/rcmunin-node
%dir %{_sysconfdir}/munin/plugin-conf.d
%dir %{_sysconfdir}/munin/plugins
%config(noreplace) %{_sysconfdir}/munin/plugin-conf.d/munin-node
%config(noreplace) %{_sysconfdir}/munin/munin-node.conf
%config %{_sysconfdir}/logrotate.d/munin-node
%dir %{perl_vendorlib}/Munin/Common
%{perl_vendorlib}/Munin/Common/Config.pm
%{perl_vendorlib}/Munin/Common/Daemon.pm
%{perl_vendorlib}/Munin/Common/Defaults.pm
%{perl_vendorlib}/Munin/Common/TLS.pm
%{perl_vendorlib}/Munin/Common/TLSClient.pm
%{perl_vendorlib}/Munin/Common/TLSServer.pm
%{perl_vendorlib}/Munin/Common/Timeout.pm
%{perl_vendorlib}/Munin/Common/DictFile.pm
%{perl_vendorlib}/Munin/Common/SyncDictFile.pm
%dir %{perl_vendorlib}/Munin/Node
%{perl_vendorlib}/Munin/Node/Config.pm
%dir %{perl_vendorlib}/Munin/Node/Configure
%{perl_vendorlib}/Munin/Node/Configure/Debug.pm
%{perl_vendorlib}/Munin/Node/Configure/History.pm
%{perl_vendorlib}/Munin/Node/Configure/HostEnumeration.pm
%{perl_vendorlib}/Munin/Node/Configure/Plugin.pm
%{perl_vendorlib}/Munin/Node/Configure/PluginList.pm
%{perl_vendorlib}/Munin/Node/Logger.pm
%{perl_vendorlib}/Munin/Node/OS.pm
%{perl_vendorlib}/Munin/Node/SNMPConfig.pm
%{perl_vendorlib}/Munin/Node/Server.pm
%{perl_vendorlib}/Munin/Node/Service.pm
%{perl_vendorlib}/Munin/Node/Session.pm
%{perl_vendorlib}/Munin/Node/Utils.pm
%{perl_vendorlib}/Munin/Node/SpoolReader.pm
%{perl_vendorlib}/Munin/Node/SpoolWriter.pm
%{perl_vendorlib}/Munin/Plugin.pm
%dir %{perl_vendorlib}/Munin/Plugin
%{perl_vendorlib}/Munin/Plugin/Pgsql.pm
%{perl_vendorlib}/Munin/Plugin/SNMP.pm
%{_mandir}/man1/munin-node-configure.1%{?ext_man}
%{_mandir}/man1/munin-node.1%{?ext_man}
%{_mandir}/man1/munin-run.1%{?ext_man}
%{_mandir}/man1/munindoc.1%{?ext_man}
%{_mandir}/man1/munin-get.1%{?ext_man}
%{_mandir}/man3/Munin::Common::Config.3pm.gz
%{_mandir}/man3/Munin::Common::Daemon.3pm.gz
%{_mandir}/man3/Munin::Common::Defaults.3pm.gz
%{_mandir}/man3/Munin::Common::TLS.3pm.gz
%{_mandir}/man3/Munin::Common::TLSClient.3pm.gz
%{_mandir}/man3/Munin::Common::TLSServer.3pm.gz
%{_mandir}/man3/Munin::Common::Timeout.3pm.gz
%{_mandir}/man3/Munin::Node::Config.3pm.gz
%{_mandir}/man3/Munin::Node::Configure::Debug.3pm.gz
%{_mandir}/man3/Munin::Node::Configure::History.3pm.gz
%{_mandir}/man3/Munin::Node::Configure::HostEnumeration.3pm.gz
%{_mandir}/man3/Munin::Node::Configure::Plugin.3pm.gz
%{_mandir}/man3/Munin::Node::Configure::PluginList.3pm.gz
%{_mandir}/man3/Munin::Node::Logger.3pm.gz
%{_mandir}/man3/Munin::Node::OS.3pm.gz
%{_mandir}/man3/Munin::Node::SpoolReader.3pm.gz
%{_mandir}/man3/Munin::Node::SpoolWriter.3pm.gz
%{_mandir}/man3/Munin::Node::SNMPConfig.3pm.gz
%{_mandir}/man3/Munin::Node::Server.3pm.gz
%{_mandir}/man3/Munin::Node::Service.3pm.gz
%{_mandir}/man3/Munin::Node::Session.3pm.gz
%{_mandir}/man3/Munin::Node::Utils.3pm.gz
%{_mandir}/man3/Munin::Plugin.3pm.gz
%{_mandir}/man3/Munin::Plugin::Pgsql.3pm.gz
%{_mandir}/man3/Munin::Plugin::SNMP.3pm.gz
%attr(0750, munin, munin) %dir %{logdir}
%attr(0755, munin, munin) %dir %{dbdir}
%attr(0775, nobody, nobody) %dir %{dbdir}/plugin-state
%ghost %{logdir}/munin-node.log
%ghost /run/munin
%dir %{_prefix}/lib/firewalld
%dir %{_prefix}/lib/firewalld/services
%{_prefix}/lib/firewalld/services/munin-node.xml

%changelog
* Sun Sep 29 2024 Thorsten Kukuk <kukuk@suse.com>
- Add /srv/www directories to filelist [bsc#1231027]
* Thu Jun 13 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Fix dependenices: the FastCGI perl module is called FCGI.
* Wed Jun 12 2024 Dirk Stoecker <opensuse@dstoecker.de>
- remove package name based perl requires
* Mon Mar 18 2024 pgajdos@suse.com
- remove dependency on /usr/bin/python3 using
  %%python3_fix_shebang_path macro, [bsc#1212476]
* Thu Feb 22 2024 pgajdos@suse.com
- Use %%patch -P N instead of deprecated %%patchN.
* Mon Jan 22 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Provide user(munin) and group(munin): the user and group are
  created during in the pre script.
* Mon Jan 15 2024 Pedro Monreal <pmonreal@suse.com>
- Use IO::Socket::IP instead of IO::Socket::INET[6]
  * Remove the dependency on perl(IO::Socket::INET6) as it has been
    deprecated by upstream, is no longer suitable for use and its not
    being maintained. A compatible replacement for this package is
    perl(IO::Socket::IP) which is shipped by the perl-base package.
  * Upstream commit back-ported:
    https://github.com/munin-monitoring/munin/commit/012b33a7
  * Add upstream munin-remove-deprecated-INET6.patch
* Tue May  2 2023 Bernhard Wiedemann <bwiedemann@suse.com>
- Drop manual requires for python (boo#1210588)
* Fri Apr 21 2023 Max Lin <mlin@suse.com>
- Use python3 as the interpreter in ipmi_sensor_ and
  smart_, boo#1210588
* Sun Mar 12 2023 Carsten Ziepke <kieltux@gmail.com>
- Update to 2.0.72
  * Import custom css file in style-new.css
* Thu Jan 12 2023 Bernhard Wiedemann <bwiedemann@suse.com>
- Drop harmful chown in %%post scripts (boo#1155078)
* Thu Dec 15 2022 Carsten Ziepke <kieltux@gmail.com>
- Update to 2.0.71
  * fix the fix for Date::Manip
- Changes in 2.0.70
  * plugins/http_loadtime: enable saving cookies between requests
  * UpdateWorker: prevent use of uninitialized value $first_epoch
  * fix html_strategy to point to munin-cgi-html
  * plugin fail2ban: allow configuration of warning/critical
    thresholds
  * Plugin haproxy_: handle backends with special characters
  * [snmp__df_ram] Update title to match the memory plugin
  * [snmp__cpuload] Update title to match the cpu plugin
  * Plugin df_inode : Exclude msdosfs on FreeBSD as there's no
    concept of inode
  * Plugin bind9: stabilize order of values in graph
  * Plugin bind9: Author's blog has moved to .no TLD
  * Plugin bind9: Move 'Other' to bottom of list
  * Update munin-graph.in
  * Update munin-cgi-graph.in
- Run spec-cleaner
- Fix rpmlint warning: This script uses 'env' as an interpreter.
* Mon Oct 24 2022 Ludwig Nussel <lnussel@suse.de>
- UsrMerge: move stuff from /sbin to /usr/sbin (boo#1191080)
* Sun Feb 20 2022 Wolfgang Rosenauer <wr@rosenauer.org>
- update to 2.0.69
  * bugfixes
  * Handle NVME drives in the Linux iostat plugin
  * munin-run: allow to pass additional arguments to the plugin
  * use dedicated munin SNMP plugin
- require the www group (boo#1195732)
* Mon Nov 29 2021 Johannes Segitz <jsegitz@suse.com>
- Removed
  * PrivateDevices=true
  * ProtectClock=true
  * RestrictRealtime=true
  from munin-node.service (bsc#1193118)
* Thu Oct  7 2021 Johannes Segitz <jsegitz@suse.com>
- Added hardening to systemd service(s) (bsc#1181400). Modified:
  * munin-cgi-graph.service
  * munin-cgi-html.service
  * munin-cron.service
  * munin-node.service
* Fri Mar  5 2021 Thorsten Kukuk <kukuk@suse.com>
- Run munin-update as user munin [bsc#1183078]
* Tue Feb 23 2021 Andreas Stieger <andreas.stieger@gmx.de>
- add upstream singing key and verify source signature
* Mon Feb  8 2021 Dirk Müller <dmueller@suse.com>
- update to 2.0.66:
  * unknown_limit: do not misinterpret zero as one
  * unknown_limit: fix handling of value "1"
  * SpoolReader: process spooled content lines separately
  * async: fetch spooled data in order of timestamps
  * async: use name squashing rules when determining the names of spooled files
  * async: clarify handling of timestamp
  * doc: describe "timeout_fetch_all_nodes" and "timeout_fetch_one_node"
  * Make sensors_ temperature plugin work on musl libc
  * Symlink and custom name support for diskstat_
  * fix reporting on URL in the munin-update log (stable-2.0)
  * make it possible to configure global munin-update timeouts
  * Use configured plugin group as primary group
  * plugins/memory: add per-cpu counter
  * Munin thresholds support for http_loadtime
  * adjust_threshold: strings indexes are 1 based in AWK
  * Plugin apt_all: prevent ambiguity between slash and hyphen in release names
  * Fix utf8 encoding in plugins
  * Fix special character for author name (Kristian Lyngst370l)
  * Plugin snmp__if_err_: clarify authors list
  * Plugin nomadix_users_: clarify formatting of authors
  * Plugin vserver_cpu_: clarify copyright statement
  * Plugin snmp__uptime: clarify authors
  * Unify spelling of author "Dagfinn Ilmari Manns345ker"
  * Unify more author names
  * Fix template error in case of an empty host list
* Tue Sep 29 2020 Thorsten Kukuk <kukuk@suse.com>
- pwdutils is long gone, use shadow
- Don't hard require systemd
- Update to 2.0.64
  * several bugfixes in minor releases
  https://github.com/munin-monitoring/munin/blob/stable-2.0/ChangeLog
* Wed Aug 19 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Stop abusing %%{_libexecdir} for the firewalld service files.
* Sat Mar 21 2020 Wolfgang Rosenauer <wr@rosenauer.org>
- add service definition for firewalld
* Fri Feb 21 2020 Wolfgang Rosenauer <wr@rosenauer.org>
- update to 2.0.56
  * several bugfixes in minor releases
  https://github.com/munin-monitoring/munin/blob/stable-2.0/ChangeLog
* Tue Sep 10 2019 Wolfgang Rosenauer <wr@rosenauer.org>
- use systemd timer instead of cron for new distributions (boo#1115448)
- require perl-rrdtool (boo#1149880)
- removed old (non-systemd) conditionals from spec
* Tue Aug 20 2019 kukuk@suse.de
- Package /etc/cron.d as this is now part of cron which we don't
  want to require
* Wed Jun 12 2019 dimstar@opensuse.org
- Allow OBS to pick better candidates to shorten rebuild queues
* Thu May  9 2019 Mathias Homann <Mathias.Homann@opensuse.org>
- update to 2.0.49
  * fixes and improvements
* Mon May  6 2019 Mathias Homann <Mathias.Homann@opensuse.org>
- update to 2.0.48
  * many fixes and improvements in plugins
* Tue Sep  4 2018 wr@rosenauer.org
- update to 2.0.40
  * many fixes and improvements in plugins
  * fixes and improvements of the build system
- removed obsolete patch
  munin-plugin-quota_usage_warnings.patch
* Mon May 28 2018 wr@rosenauer.org
- update to 2.0.37
  * Add support for IBM i
  * Update lighttpd.rst
  * Update nginx.rst
  * ejabberd improvements
  * add example plugin graphs
  * Add support for MySQL 5.5/5.6
  * Added HP-UX support to processes plugin
  * snmp__if_multi: Set warning to 75%% of interface speed instead of 133%%
  * Add support for rndc options in bind9_rndc plugin
  * Correcting mysql_queries plugin random hash ordering
  * Add PostgreSQL 10 support to postgres_xlog
  * mysql improvements
  * Add IPv6 support
  * many other improvements
- require also perl-rrdtool where it exists (boo#1094776)
- remove obsolete mysql55.patch
* Fri Sep 29 2017 coolo@suse.com
- add perl526.patch to compile with perl 5.26 (no more . in @INC)
* Fri Jun  2 2017 suse-beta@cboltz.de
- add Requires(pre): user(nobody) and group(nobody) to munin-node to fix
  Tumbleweed build
- add %%ghost /run/munin to munin and munin-node to fix a rpmlint warning
  (Tumbleweed only, would cause build failures on SLE11)
* Thu Mar  2 2017 aj@ajaissle.de
- fix source url
- update to 2.0.32
- remove CVE-2017-6188-fix-parameter-injection.patch (applied upstream)
* Thu Feb 23 2017 wr@rosenauer.org
- fix CVE-2017-6188: munin-cgi-graph local file write vulnerability
  (boo#1026539, CVE-2017-6188-fix-parameter-injection.patch)
* Sun Feb 19 2017 wr@rosenauer.org
- update to version 2.0.30
  Bugfix releases (closes the following issues since 2.0.25)
  2.0.26: Closes: D:761190, GH:426
  2.0.27: Closes: D:767032, D:768553, D:825136, D:834194, GH:690, GH:714
  2.0.29: Closes: D:847649, D:849383
  2.0.30: Closes: GH:745, GH:771, GH:783
* Tue Jan 17 2017 bwiedemann@suse.com
- override build host's hostname to make build reproducible
* Tue Nov 24 2015 wr@rosenauer.org
- apply upstream change to work correctly for MySQL >= 5.5
  (mysql55.patch
* Tue Sep  1 2015 dimstar@opensuse.org
- Add perl(Module::Build) BuildRequires: Fix build with perl 5.22.
* Sun Aug  2 2015 bwiedemann@suse.com
- fix munin-node start (bnc#940287)
* Wed Jan  7 2015 wr@rosenauer.org
- update to version 2.0.25
  Bugfix release.
  Closes: GH:304, D:769415, D:770745, D:770746, D:770826
  * p/irqstats: Improve generated labels
  * ip/iostat_ios: also support /dev/xvdX devices
  * p/iostat_ios: also support /dev/vdX devices
  * plugins/df_abs: fix the naming for regular devices
  * p/pgsql: Detect "rc" postgresql versions
  * p/ping_: honor ping env variable
- cleanup sysvinit scriptlets to fix the issue which always
  disabled the service on update
* Sun Nov  2 2014 wr@rosenauer.org
- update to version 2.0.24
  * bugfix release
    compatibility with perl 5.20
* Sat Sep 27 2014 wr@rosenauer.org
- update to version 2.0.21
  * bugfix release
    It fixes the "start should be less than end" bug.
* Fri Sep 12 2014 darin@darins.net
- remove conditions on Sources and include them regardless
* Thu Jan 16 2014 wr@rosenauer.org
- require perl-libwww-perl to enable apache plugins (bnc#859046)
* Sat Dec 21 2013 wr@rosenauer.org
- recommend logdigest to allow removal of it w/o breaking deps
  (munin-node likes to have logtail which is part of logdigest
  but the daily cronjob of logdigest is probably unwanted on some
  systems)
* Tue Dec 17 2013 wr@rosenauer.org
- update to version 2.0.19 (bnc#853570)
  * CVE-2013-6048, a node could cause excessive memory consumption
    on the Munin master
  * CVE-2013-6359, a malicious plug-in could prevent data collection
    for the node.
  * more bugfixes
* Tue Aug 20 2013 opensuse@dstoecker.de
- fix requires for main munin package
* Mon May 27 2013 draht@suse.de
- update to version 2.0.14:
  * fixes for computing of absolute values
  * timeout code decoupled for global and plugin timeout.
  * fixes for ntp
  * TMPDIR reuse fixes
- do NOT autostart from %%post
* Tue May 21 2013 vjt@openssl.it
- Add missing perl-URI and perl-FastCGI dependencies
- Add systemd service units to start the HTML and Graph CGI servers
  with the aid of spawn-fcgi
  NOTE: the FastCGI server listens on an UNIX socket in /var/run/munin
  and members of the "www" group can write to it.
- Add the missing [Install] section of the munin-node service unit
* Mon Mar 25 2013 vjt@openssl.it
- Add an SNMP wildcard plugin to monitor the Google Search Appliance
    https://github.com/ifad/munin-gsa
* Wed Mar 13 2013 vjt@openssl.it
- Include an improved quota usage plugin that gets warning and
  critical values from the configured soft and hard quotas.
  Found in the wild on
    https://svn.koumbit.net/koumbit/trunk/munin-plugins/quota-usage
  tested and adapted.
* Thu Mar  7 2013 vjt@openssl.it
- Update to 2.0.11.1
- Add nginx plugins from http://github.com/ifad/nginx-munin
* Tue Mar  5 2013 vjt@openssl.it
- BuildRequire perl-IO-Socket-INET6
* Thu May  3 2012 wr@rosenauer.org
- update to bugfix release 1.4.7
- fixed CVE-2012-2147 (bnc#759910)
* Wed Jun  9 2010 detlef@links2linux.de
- new upstream version <1.4.5>
  * bugfix release
* Sat Mar  6 2010 detlef@links2linux.de
- new upstream version <1.4.4>
* Thu Dec 31 2009 detlef@links2linux.de
- new upstream release <1.4.3>
* Mon Dec 21 2009 detlef@links2linux.de
- new upstream release <1.4.2>
* Mon Dec  7 2009 detlef@links2linux.de
- new upstream release <1.4.1>
* Sat Nov 28 2009 detlef@links2linux.de
- new upstream release <1.4.0>
* Sat Dec 27 2008 detlef@links2linux.de
- add UTF8 patch
* Sat Jul 19 2008 detlef@links2linux.de
- new upstream release <1.2.6>
* Wed Aug 15 2007 detlef@links2linux.de
- new upstream release <1.2.5>
* Mon Oct 17 2005 detlef@links2linux.de
- Fixed missing /sbin/rcmunin-node
* Sun Oct 16 2005 detlef@links2linux.de
- First build for packman
* Sun Apr  3 2005 runesk@linpro.no
- 1.2.3 release
* Fri Apr  1 2005 runesk@linpro.no
- 1.2.2 release
- Fixed SF bug 1164481 (missing /srv/www/htdocs/munin)
- Fixed SF bug 1164477 (patch for Net::Domain on PPC64)
* Fri Mar 11 2005 runesk@linpro.no
- 1.2.1 release
* Wed Mar  9 2005 runesk@linpro.no
- Fixed erronumous path to web directory
- Added start of node if not running
* Tue Mar  8 2005 runesk@linpro.no
- Fixed some build path problems
* Thu Feb 24 2005 runesk@linpro.no
- New major release
* Wed Feb  9 2005 runesk@linpro.no
- Updated to version 1.2.0rc2.
- Removed Nagios stuff
- Added noreplace for some central configuration files
* Thu Nov 18 2004 runesk@linpro.no
- Updated to version 1.0.4
* Mon Nov  8 2004 runesk@linpro.no
- Updated version 1.0.3 / sync with redhat-build
* Wed Aug  4 2004 runesk@linpro.no
- Initial SuSE build
* Sun Feb  1 2004 ingvar@linpro.no
- Sync with CVS. Version 1.0.0pre2
* Sun Jan 18 2004 ingvar@linpro.no
- Sync with CVS. Change names to munin.
* Fri Oct 31 2003 ingvar@linpro.no
- Lot of small fixes. Now builds on more RPM distros
* Wed May 21 2003 ingvar@linpro.no
- Sync with CVS
- 0.9.5-1
* Tue Apr  1 2003 ingvar@linpro.no
- Sync with CVS
- Makefile-based install of core files
- Build doc (only pod2man)
* Thu Jan  9 2003 ingvar@linpro.no
- Sync with CVS, auto rpmbuild
* Thu Jan  2 2003 ingvar@linpro.no
- Fix spec file for RedHat 8.0 and new version of lrrd
* Wed Sep  4 2002 ingvar@linpro.no
- Small bugfixes in the rpm package
* Tue Jun 18 2002 kjetilho@linpro.no
- new package
